# python_exp_learning
This repository contains activities for learning  coding skills in python.


# Getting Started

```
>>> conda env create -f env.yaml
```

```
>>> conda activate mathstro_veh_env
```

## For Development
```
>>> pip install -e .[dev]
```

## For Non-Development Purposes
```
>>> pip install -e
```
